Harness
=======

Harness is a language-neutral meta-framework for building a serverless-style
services.

Installation
~~~~~~~~~~~~

.. code-block:: console

  $ pip3 install harness
  $ brew install protobuf
